@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.i18n import gettext
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
 
 from .exceptions import OverShipmentWarning
 
@@ -37,7 +37,7 @@ class Line(metaclass=PoolMeta):
         # Compute tolerance only if there is already at least one move.
         if move and set(self.moves) - set(self.moves_recreated):
             quantity = Uom.compute_qty(
-                move.uom, move.quantity, self.unit, round=False)
+                move.unit, move.quantity, self.unit, round=False)
             if self._test_under_shipment_tolerance(quantity):
                 move = None
         return move
@@ -66,7 +66,5 @@ class Line(metaclass=PoolMeta):
                         name,
                         gettext('sale_shipment_tolerance.msg_over_shipment',
                             line=self.rec_name,
-                            shipped=lang.format(
-                                '%f', shipped_quantity),
-                            maximal=lang.format(
-                                '%f', maximal_quantity)))
+                            shipped=lang.format_number(shipped_quantity),
+                            maximal=lang.format_number(maximal_quantity)))
